"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.tenantIndex = exports.reinstall = exports.baseVersion = exports.r11sEndpointName = exports.driver = exports.compatVersions = exports.compatKind = exports.CompatKind = void 0;
const nconf_1 = __importDefault(require("nconf"));
const versionUtils_1 = require("./versionUtils");
const packageVersion_1 = require("./packageVersion");
/**
 * Different kind of compat version config
 */
var CompatKind;
(function (CompatKind) {
    CompatKind["None"] = "None";
    CompatKind["Loader"] = "Loader";
    CompatKind["NewLoader"] = "NewLoader";
    CompatKind["Driver"] = "Driver";
    CompatKind["NewDriver"] = "NewDriver";
    CompatKind["ContainerRuntime"] = "ContainerRuntime";
    CompatKind["NewContainerRuntime"] = "NewContainerRuntime";
    CompatKind["DataRuntime"] = "DataRuntime";
    CompatKind["NewDataRuntime"] = "NewDataRuntime";
    CompatKind["LoaderDriver"] = "LoaderDriver";
})(CompatKind = exports.CompatKind || (exports.CompatKind = {}));
/*
 * Parse the command line argument and environment variables.  Arguments take precedent over environment variable
 * NOTE: Please update this packages README.md if the default versions and config combination changes
 */
const options = {
    compatKind: {
        description: "Compat kind to run",
        choices: [
            CompatKind.None,
            CompatKind.Loader,
            CompatKind.NewLoader,
            CompatKind.Driver,
            CompatKind.NewDriver,
            CompatKind.ContainerRuntime,
            CompatKind.NewContainerRuntime,
            CompatKind.DataRuntime,
            CompatKind.NewDataRuntime,
            CompatKind.LoaderDriver,
        ],
        requiresArg: true,
        array: true,
    },
    compatVersion: {
        description: "Compat version to run",
        requiresArg: true,
        array: true,
        type: "string",
    },
    reinstall: {
        default: false,
        description: "Force compat package to be installed",
        boolean: true,
    },
    driver: {
        choices: ["tinylicious", "t9s", "routerlicious", "r11s", "odsp", "local"],
        requiresArg: true,
    },
    r11sEndpointName: {
        type: "string",
    },
    tenantIndex: {
        type: "number",
    },
    baseVersion: {
        type: "string",
    },
};
nconf_1.default
    .argv(Object.assign(Object.assign({}, options), { transform: (obj) => {
        if (options[obj.key] !== undefined) {
            obj.key = `fluid:test:${obj.key}`;
        }
        return obj;
    } }))
    .env({
    separator: "__",
    whitelist: [
        "fluid__test__compatKind",
        "fluid__test__compatVersion",
        "fluid__test__driver",
        "fluid__test__r11sEndpointName",
        "fluid__test__baseVersion",
    ],
    transform: (obj) => {
        var _a;
        if (!obj.key.startsWith("fluid__test__")) {
            return obj;
        }
        const key = obj.key.substring("fluid__test__".length);
        if ((_a = options[key]) === null || _a === void 0 ? void 0 : _a.array) {
            try {
                obj.value = JSON.parse(obj.value);
            }
            catch (_b) {
                // ignore
            }
        }
        return obj;
    },
})
    .defaults({
    fluid: {
        test: {
            driver: "local",
            baseVersion: packageVersion_1.pkgVersion,
            r11sEndpointName: "r11s",
            tenantIndex: 0,
        },
    },
});
exports.compatKind = nconf_1.default.get("fluid:test:compatKind");
exports.compatVersions = nconf_1.default.get("fluid:test:compatVersion");
exports.driver = nconf_1.default.get("fluid:test:driver");
exports.r11sEndpointName = nconf_1.default.get("fluid:test:r11sEndpointName");
exports.baseVersion = (0, versionUtils_1.resolveVersion)(nconf_1.default.get("fluid:test:baseVersion"), false);
exports.reinstall = nconf_1.default.get("fluid:test:reinstall");
exports.tenantIndex = nconf_1.default.get("fluid:test:tenantIndex");
//# sourceMappingURL=compatOptions.js.map